@@ -1,19 +1,9 @@
-/***************************************************************************
-                     read a KEduVocDocument from a WQL file
-    -----------------------------------------------------------------------
-    copyright     : (C) 2004, 2007 Peter Hedlund <peter.hedlund@kdemail.net>
-                  : (c) 2005 Eric Pignet
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+ * read a KEduVocDocument from a WQL file
+ * SPDX-FileCopyrightText: 2004, 2007 Peter Hedlund <peter.hedlund@kdemail.net>
+ * SPDX-FileCopyrightText: 2005 Eric Pignet
+ * SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KEDUVOCWQLREADER_H
 #define KEDUVOCWQLREADER_H
